0.9.9 API documentation: exterior_product.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

exterior_product.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependencies
17 #include "../detail/setup.hpp"
18 #include "../detail/qualifier.hpp"
19
20 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
21 # ifndef GLM_ENABLE_EXPERIMENTAL
22 # pragma message("GLM: GLM_GTX_exterior_product is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
23 # else
24 # pragma message("GLM: GLM_GTX_exterior_product extension included")
25 # endif
26 #endif
27
28 namespace glm
29 {
32
39 template<typename T, qualifier Q>
40 GLM_FUNC_DECL T cross(vec<2, T, Q> const& v, vec<2, T, Q> const& u);
41
43 } //namespace glm
44
45 #include "exterior_product.inl"
glm::cross
GLM_FUNC_DECL T cross(vec< 2, T, Q > const &v, vec< 2, T, Q > const &u)
Returns the cross product of x and y.
glm
Definition: common.hpp:20